@@ -63,6 +63,7 @@ import files_sdk.models.remote_server as remote_server
 import files_sdk.models.request as request
 import files_sdk.models.session as session
 import files_sdk.models.settings_change as settings_change
+import files_sdk.models.sftp_host_key as sftp_host_key
 import files_sdk.models.site as site
 import files_sdk.models.sso_strategy as sso_strategy
 import files_sdk.models.status as status
@@ -138,6 +139,7 @@ from files_sdk.models.remote_server import RemoteServer
 from files_sdk.models.request import Request
 from files_sdk.models.session import Session
 from files_sdk.models.settings_change import SettingsChange
+from files_sdk.models.sftp_host_key import SftpHostKey
 from files_sdk.models.site import Site
 from files_sdk.models.sso_strategy import SsoStrategy
 from files_sdk.models.status import Status
