@@ -21,9 +21,11 @@ class Bundle:
         'skip_company': None,     # boolean - BundleRegistrations can be saved without providing company?
         'id': None,     # int64 - Bundle ID
         'created_at': None,     # date-time - Bundle created at date/time
+        'dont_separate_submissions_by_folder': None,     # boolean - Do not create subfolders for files uploaded to this share. Note: there are subtle security pitfalls with allowing anonymous uploads from multiple users to live in the same folder. We strongly discourage use of this option unless absolutely required.
         'expires_at': None,     # date-time - Bundle expiration date/time
         'max_uses': None,     # int64 - Maximum number of times bundle can be accessed
         'note': None,     # string - Bundle internal note
+        'path_template': None,     # string - Template for creating submission subfolders. Can use the uploader's name, email address, ip, company, and any custom form data.
         'user_id': None,     # int64 - Bundle creator user ID
         'username': None,     # string - Bundle creator username
         'clickwrap_id': None,     # int64 - ID of the clickwrap to use with this bundle.
@@ -87,10 +89,12 @@ class Bundle:
     #   clickwrap_id - int64 - ID of the clickwrap to use with this bundle.
     #   code - string - Bundle code.  This code forms the end part of the Public URL.
     #   description - string - Public description
+    #   dont_separate_submissions_by_folder - boolean - Do not create subfolders for files uploaded to this share. Note: there are subtle security pitfalls with allowing anonymous uploads from multiple users to live in the same folder. We strongly discourage use of this option unless absolutely required.
     #   expires_at - string - Bundle expiration date/time
     #   inbox_id - int64 - ID of the associated inbox, if available.
     #   max_uses - int64 - Maximum number of times bundle can be accessed
     #   note - string - Bundle internal note
+    #   path_template - string - Template for creating submission subfolders. Can use the uploader's name, email address, ip, company, and any custom form data.
     #   permissions - string - Permissions that apply to Folders in this Share Link.
     #   preview_only - boolean - Restrict users to previewing files only?
     #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
@@ -132,6 +136,8 @@ class Bundle:
             raise InvalidParameterError("Bad parameter: max_uses must be an int")
         if "note" in params and not isinstance(params["note"], str):
             raise InvalidParameterError("Bad parameter: note must be an str")
+        if "path_template" in params and not isinstance(params["path_template"], str):
+            raise InvalidParameterError("Bad parameter: path_template must be an str")
         if "permissions" in params and not isinstance(params["permissions"], str):
             raise InvalidParameterError("Bad parameter: permissions must be an str")
         response, _options = Api.send_request("PATCH", "/bundles/{id}".format(id=params['id']), params, self.options)
@@ -226,11 +232,13 @@ def get(id, params = None, options = None):
 #   paths (required) - array(string) - A list of paths to include in this bundle.
 #   password - string - Password for this bundle.
 #   form_field_set_id - int64 - Id of Form Field Set to use with this bundle
+#   dont_separate_submissions_by_folder - boolean - Do not create subfolders for files uploaded to this share. Note: there are subtle security pitfalls with allowing anonymous uploads from multiple users to live in the same folder. We strongly discourage use of this option unless absolutely required.
 #   expires_at - string - Bundle expiration date/time
 #   max_uses - int64 - Maximum number of times bundle can be accessed
 #   description - string - Public description
 #   note - string - Bundle internal note
 #   code - string - Bundle code.  This code forms the end part of the Public URL.
+#   path_template - string - Template for creating submission subfolders. Can use the uploader's name, email address, ip, company, and any custom form data.
 #   permissions - string - Permissions that apply to Folders in this Share Link.
 #   preview_only - boolean - Restrict users to previewing files only?
 #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
@@ -264,6 +272,8 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: note must be an str")
     if "code" in params and not isinstance(params["code"], str):
         raise InvalidParameterError("Bad parameter: code must be an str")
+    if "path_template" in params and not isinstance(params["path_template"], str):
+        raise InvalidParameterError("Bad parameter: path_template must be an str")
     if "permissions" in params and not isinstance(params["permissions"], str):
         raise InvalidParameterError("Bad parameter: permissions must be an str")
     if "clickwrap_id" in params and not isinstance(params["clickwrap_id"], int):
@@ -307,10 +317,12 @@ def share(id, params = None, options = None):
 #   clickwrap_id - int64 - ID of the clickwrap to use with this bundle.
 #   code - string - Bundle code.  This code forms the end part of the Public URL.
 #   description - string - Public description
+#   dont_separate_submissions_by_folder - boolean - Do not create subfolders for files uploaded to this share. Note: there are subtle security pitfalls with allowing anonymous uploads from multiple users to live in the same folder. We strongly discourage use of this option unless absolutely required.
 #   expires_at - string - Bundle expiration date/time
 #   inbox_id - int64 - ID of the associated inbox, if available.
 #   max_uses - int64 - Maximum number of times bundle can be accessed
 #   note - string - Bundle internal note
+#   path_template - string - Template for creating submission subfolders. Can use the uploader's name, email address, ip, company, and any custom form data.
 #   permissions - string - Permissions that apply to Folders in this Share Link.
 #   preview_only - boolean - Restrict users to previewing files only?
 #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
@@ -348,6 +360,8 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: max_uses must be an int")
     if "note" in params and not isinstance(params["note"], str):
         raise InvalidParameterError("Bad parameter: note must be an str")
+    if "path_template" in params and not isinstance(params["path_template"], str):
+        raise InvalidParameterError("Bad parameter: path_template must be an str")
     if "permissions" in params and not isinstance(params["permissions"], str):
         raise InvalidParameterError("Bad parameter: permissions must be an str")
     if "id" not in params:
