@@ -22,12 +22,21 @@ class User:
         'dav_permission': None,     # boolean - Can the user connect with WebDAV?
         'disabled': None,     # boolean - Is user disabled? Disabled users cannot log in, and do not count for billing purposes.  Users can be automatically disabled after an inactivity period via a Site setting.
         'email': None,     # email - User email address
+        'first_login_at': None,     # date-time - User's first login time
         'ftp_permission': None,     # boolean - Can the user access with FTP/FTPS?
         'group_ids': None,     # string - Comma-separated list of group IDs of which this user is a member
         'header_text': None,     # string - Text to display to the user in the header of the UI
         'language': None,     # string - Preferred language
-        'last_login_at': None,     # date-time - User's last login time
-        'last_protocol_cipher': None,     # string - The last protocol and cipher used
+        'last_login_at': None,     # date-time - User's most recent login time via any protocol
+        'last_web_login_at': None,     # date-time - User's most recent login time via web
+        'last_ftp_login_at': None,     # date-time - User's most recent login time via FTP
+        'last_sftp_login_at': None,     # date-time - User's most recent login time via SFTP
+        'last_dav_login_at': None,     # date-time - User's most recent login time via WebDAV
+        'last_desktop_login_at': None,     # date-time - User's most recent login time via Desktop app
+        'last_restapi_login_at': None,     # date-time - User's most recent login time via Rest API
+        'last_api_use_at': None,     # date-time - User's most recent API use time
+        'last_active_at': None,     # date-time - User's most recent activity time, which is the latest of most recent login, most recent API use, enablement, or creation
+        'last_protocol_cipher': None,     # string - The most recent protocol and cipher used
         'lockout_expires': None,     # date-time - Time in the future that the user will no longer be locked out if applicable
         'name': None,     # string - User's full name
         'company': None,     # string - User's company
@@ -53,6 +62,7 @@ class User:
         'externally_managed': None,     # boolean - Is this user managed by a SsoStrategy?
         'time_zone': None,     # string - User time zone
         'type_of_2fa': None,     # string - Type(s) of 2FA methods in use.  Will be either `sms`, `totp`, `u2f`, `yubi`, or multiple values sorted alphabetically and joined by an underscore.
+        'updated_at': None,     # date-time - User record most recently updated at.  Note this may be incremented because of internal or external updates.
         'user_root': None,     # string - Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set.)  Note that this is not used for API, Desktop, or Web interface.
         'avatar_file': None,     # file - An image file for your user avatar.
         'avatar_delete': None,     # boolean - If true, the avatar will be deleted.
